.. hckr documentation master file, created by
   sphinx-quickstart on Wed Jun 12 20:06:39 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Cryptography
===============
``hckr`` supports a variety of cryptographic commands to ensure the security and authenticity of communication and data. Following are some of the commands we support:

* **fernet**: It is an implementation of symmetric (also known as “secret key”) authenticated cryptography.

.. tip::
   More commands will be added in future updates. Stay tuned!

commands
---------------

.. toctree::
    fernet

